@@ -11,10 +11,10 @@ class Regions:
         self.mask = mask
 
     @property
-    def _mask_2d_index_for_mask_1d_index(self):
+    def _mask_index_for_mask_1d_index(self):
         """A 1D array of mappings between every unmasked pixel and its 2D pixel coordinates."""
-        return mask_util.sub_mask_2d_index_for_sub_mask_1d_index_via_mask_2d(
-            mask_2d=self.mask, sub_size=1
+        return mask_util.sub_mask_index_for_sub_mask_1d_index_via_mask_from(
+            mask=self.mask, sub_size=1
         ).astype("int")
 
     @property
@@ -22,16 +22,14 @@ class Regions:
         """The indicies of the mask's edge pixels, where an edge pixel is any unmasked pixel on its edge \
         (next to at least one pixel with a *True* value).
         """
-        return mask_util.edge_1d_indexes_from_mask_2d(mask_2d=self.mask).astype("int")
+        return mask_util.edge_1d_indexes_from(mask=self.mask).astype("int")
 
     @property
     def _edge_2d_indexes(self):
         """The indicies of the mask's edge pixels, where an edge pixel is any unmasked pixel on its edge \
         (next to at least one pixel with a *True* value).
         """
-        return self._mask_2d_index_for_mask_1d_index[self._edge_1d_indexes].astype(
-            "int"
-        )
+        return self._mask_index_for_mask_1d_index[self._edge_1d_indexes].astype("int")
 
     @property
     def _border_1d_indexes(self):
@@ -39,7 +37,7 @@ class Regions:
         exterior edge (e.g. next to at least one pixel with a *True* value but not central pixels like those within \
         an annulus mask).
         """
-        return mask_util.border_1d_indexes_from_mask_2d(mask_2d=self.mask).astype("int")
+        return mask_util.border_1d_indexes_from(mask=self.mask).astype("int")
 
     @property
     def _border_2d_indexes(self):
@@ -47,9 +45,7 @@ class Regions:
         exterior edge (e.g. next to at least one pixel with a *True* value but not central pixels like those within \
         an annulus mask).
         """
-        return self._mask_2d_index_for_mask_1d_index[self._border_1d_indexes].astype(
-            "int"
-        )
+        return self._mask_index_for_mask_1d_index[self._border_1d_indexes].astype("int")
 
     @property
     def _sub_border_1d_indexes(self):
@@ -57,8 +53,8 @@ class Regions:
         exterior edge (e.g. next to at least one pixel with a *True* value but not central pixels like those within \
         an annulus mask).
         """
-        return mask_util.sub_border_pixel_1d_indexes_from_mask_2d_and_sub_size(
-            mask_2d=self.mask, sub_size=self.mask.sub_size
+        return mask_util.sub_border_pixel_1d_indexes_from(
+            mask=self.mask, sub_size=self.mask.sub_size
         ).astype("int")
 
     @array_util.Memoizer()
@@ -75,12 +71,12 @@ class Regions:
         if kernel_shape_2d[0] % 2 == 0 or kernel_shape_2d[1] % 2 == 0:
             raise exc.MaskException("psf_size of exterior region must be odd")
 
-        blurring_mask = mask_util.blurring_mask_2d_from_mask_2d_and_kernel_shape_2d(
-            mask_2d=self.mask, kernel_shape_2d=kernel_shape_2d
+        blurring_mask = mask_util.blurring_mask_from(
+            mask=self.mask, kernel_shape_2d=kernel_shape_2d
         )
 
         return msk.Mask(
-            mask_2d=blurring_mask,
+            mask=blurring_mask,
             sub_size=1,
             pixel_scales=self.mask.pixel_scales,
             origin=self.mask.origin,
@@ -108,7 +104,7 @@ class Regions:
         mask = np.full(fill_value=True, shape=self.mask.shape)
         mask[self._edge_2d_indexes[:, 0], self._edge_2d_indexes[:, 1]] = False
         return msk.Mask(
-            mask_2d=mask,
+            mask=mask,
             sub_size=self.mask.sub_size,
             pixel_scales=self.mask.pixel_scales,
             origin=self.mask.origin,
@@ -123,17 +119,17 @@ class Regions:
         mask = np.full(fill_value=True, shape=self.mask.shape)
         mask[self._border_2d_indexes[:, 0], self._border_2d_indexes[:, 1]] = False
         return msk.Mask(
-            mask_2d=mask,
+            mask=mask,
             sub_size=self.mask.sub_size,
             pixel_scales=self.mask.pixel_scales,
             origin=self.mask.origin,
         )
 
     @property
-    def _sub_mask_2d_index_for_sub_mask_1d_index(self):
+    def _sub_mask_index_for_sub_mask_1d_index(self):
         """A 1D array of mappings between every unmasked sub pixel and its 2D sub-pixel coordinates."""
-        return mask_util.sub_mask_2d_index_for_sub_mask_1d_index_via_mask_2d(
-            mask_2d=self.mask, sub_size=self.mask.sub_size
+        return mask_util.sub_mask_index_for_sub_mask_1d_index_via_mask_from(
+            mask=self.mask, sub_size=self.mask.sub_size
         ).astype("int")
 
     @property
@@ -146,6 +142,6 @@ class Regions:
         - sub_to_pixel[8] = 2 -  The ninth sub-pixel is within the 3rd pixel.
         - sub_to_pixel[20] = 4 -  The twenty first sub-pixel is within the 5th pixel.
         """
-        return mask_util.mask_1d_index_for_sub_mask_1d_index_via_mask_2d(
-            mask_2d=self.mask, sub_size=self.mask.sub_size
+        return mask_util.mask_1d_index_for_sub_mask_1d_index_via_mask_from(
+            mask=self.mask, sub_size=self.mask.sub_size
         ).astype("int")
